// Generated by xsd compiler for ios/objective-c
// DO NOT CHANGE!

#import <Foundation/Foundation.h>
#import "PicoClassSchema.h"
#import "PicoPropertySchema.h"
#import "PicoConstants.h"
#import "PicoBindable.h"


@class Finding_Amount;

/**
 
 Contains information specific to the item listing.
 
 
 @ingroup FindingServicePortType
*/
@interface Finding_ListingInfo : NSObject <PicoBindable> {

@private
    NSNumber *_bestOfferEnabled;
    NSNumber *_buyItNowAvailable;
    Finding_Amount *_buyItNowPrice;
    Finding_Amount *_convertedBuyItNowPrice;
    NSDate *_startTime;
    NSDate *_endTime;
    NSString *_listingType;
    NSNumber *_gift;
    NSString *_delimiter;
    NSMutableArray *_any;

}


/**
 
 Shows whether or not the seller will accept a best offer for the
 associated item. Best Offer allows a buyer to make a lower-priced binding
 offer on a fixed price item. Buyers cannot see how many offers have been
 made (only the seller can see this information). To make a best offer on
 a listing, use the eBay Web site.
 
 
 type : NSNumber, wrapper for primitive bool
*/
@property (nonatomic, retain) NSNumber *bestOfferEnabled;

/**
 
 Applies only to auction listings that were listed with a Buy It Now
 price. Buy It Now lets a user purchase the item at a fixed price,
 effectively ending the auction. On most sites, the Buy It Now option is
 removed (and this value returns false) once a valid bid is made on the
 associated item (a valid bid could be a bid above the reserve price).
 <br><br>
 buyItNowAvailable will return "false" if the listing type is anything but
 "AuctionWithBIN". Please ignore buyItNowAvailable for fixed-price
 listings.
 
 
 type : NSNumber, wrapper for primitive bool
*/
@property (nonatomic, retain) NSNumber *buyItNowAvailable;

/**
 
 The Buy It Now Price of the item (if any), in the currency of the site on
 which the item was listed. You can use this field to determine if the
 item was originally listed with Buy It Now, even if the Buy It Now option
 is no longer available for the item.
 <br><br>
 For Basic Fixed-Price (FixedPrice), Store Inventory (StoreInventory), Ad
 Format (AdFormat), and Classified Ad (Classified) listings, currentPrice
 is the current fixed price.
 <br><br>
 Only returned if an item was listed with Buy It Now.
 
 
 type : class Finding_Amount
*/
@property (nonatomic, retain) Finding_Amount *buyItNowPrice;

/**
 
 The listing's Buy It Now Price (if any), converted into the currency of
 the site to which you sent your search request. For active items, refresh
 this value every 24 hours to pick up changes in conversion rates (if this
 value has been converted).
 <br><br>
 Price fields are returned as doubles, not necessarily in the traditional
 monetary format of the site's country. For example, a US Dollar value
 might be returned as 3.880001 instead of 3.88.
 <br><br>
 Only returned if an item was listed with Buy It Now.
 
 
 type : class Finding_Amount
*/
@property (nonatomic, retain) Finding_Amount *convertedBuyItNowPrice;

/**
 
 Time stamp that eBay recorded as the moment the listing was made
 available. This value is returned in GMT, the ISO 8601 date and time
 format (YYYY-MM- DDTHH:MM:SS.SSSZ). See the "dateTime" type for
 information about the time format, and for details on converting to and
 from the GMT time zone. Note that it is possible for startTime to be
 different from the value returned by GetSingleItem.
 
 
 type : NSDate, wrapper for primitive date
*/
@property (nonatomic, retain) NSDate *startTime;

/**
 
 Time stamp specifying when the listing is scheduled to end, or the
 actual end time if the item listing has ended. This value is returned in
 GMT, the ISO 8601 date and time format (YYYY-MM- DDTHH:MM:SS.SSSZ). See
 the "dateTime" type for information about the time format, and for
 details on converting to and from the GMT time zone.
 <br><br>
 <span class="tablenote"><strong>Note:</strong>
 For items that are "Good Till Canceled," this value is 5 minutes later
 than the actual end time of the item. This difference in time is
 intended to facilitate the renewal of these items' end times (which
 occurs every 30 days).
 </span>
 
 
 type : NSDate, wrapper for primitive date
*/
@property (nonatomic, retain) NSDate *endTime;

/**
 
 The format of the listing, such as online auction, fixed price, or
 advertisement.
 <dl>
 <dt>
 <strong>listingType values:</strong>
 </dt>
 <dt>
 AdFormat
 </dt>
 <dd>
 Advertisement to solicit inquiries on listings such as real estate.
 Permits no bidding on that item, service, or property. To express
 interest, a buyer fills out a contact form that eBay forwards to the
 seller as a lead. This format does not enable buyers and sellers to
 transact online through eBay and eBay Feedback is not available for
 ad format listings.
 </dd>
 <dt>
 Auction
 </dt>
 <dd>
 Competitive-bid online auction format. Buyers engage in competitive
 bidding, although Buy It Now may be offered as long as no valid bids
 have been placed. Online auctions are listed on eBay.com; they can
 also be listed in a seller's eBay Store if the seller is a Store
 owner.
 </dd>
 <dt>
 AuctionWithBIN
 </dt>
 <dd>
 Same as Auction format, but Buy It Now is enabled. AuctionWithBIN
 changes to Auction if a valid bid has been placed on the item. Valid
 bids include bids that are equal to or above any specified reserve
 price.
 </dd>
 <dt>
 Classified
 </dt>
 <dd>
 Classified Ads connect buyers and sellers, who then complete the sale
 outside of eBay. This format does not enable buyers and sellers to
 transact online through eBay and eBay Feedback is not available for
 these listing types.
 </dd>
 <dt>
 FixedPrice
 </dt>
 <dd>
 A fixed-price listing. Auction-style bidding is not allowed. On some
 sites, this auction format is also known as "Buy It Now Only" (not to
 be confused with the Buy It Now option available with competitive-
 bidding auctions). Fixed-price listings appear on eBay.com; they can
 also be listed in a seller's eBay Store if the seller is a Store
 owner.
 </dd>
 <dt>
 StoreInventory
 </dt>
 <dd>
 A fixed-price format for eBay Store sellers. Store Inventory listings
 appear after other listings in regular browse and search item
 listings on eBay. Store items have a lower Insertion Fee and longer
 listing durations. This selling type can only be specified by sellers
 who have an eBay Store. Store Inventory listings are listed on
 eBay.com as well as in the seller's eBay Store.
 </dd>
 </dl>
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *listingType;

/**
 
 If true, a generic gift icon displays next the listing's title in search
 and browse pages.
 
 
 type : NSNumber, wrapper for primitive bool
*/
@property (nonatomic, retain) NSNumber *gift;

/**
 (public property)
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *delimiter;

/**
 (public property)
 
 entry type : PicoAnyElement, wrapper for primitive anyelement
*/

@property (nonatomic, retain) NSMutableArray *any;


@end
