// Generated by xsd compiler for ios/objective-c
// DO NOT CHANGE!

#import <Foundation/Foundation.h>
#import "PicoClassSchema.h"
#import "PicoPropertySchema.h"
#import "PicoConstants.h"
#import "PicoBindable.h"



/**
 
 Type to contain the data for one eBay user. Depending on the context, the user
 might be the seller or the buyer in a transaction, or the bidder or winning bidder
 in a listing. An object of this type is returned by a number of calls, including
 the GetUser call.
 
 
 @ingroup ShoppingInterface
*/
@interface Shopping_SimpleUserType : NSObject <PicoBindable> {

@private
    NSString *_userID;
    NSNumber *_feedbackPrivate;
    NSString *_feedbackRatingStar;
    NSNumber *_feedbackScore;
    NSNumber *_userAnonymized;
    NSNumber *_newUser;
    NSDate *_registrationDate;
    NSString *_registrationSite;
    NSString *_status;
    NSString *_sellerBusinessType;
    NSString *_storeURL;
    NSString *_storeName;
    NSString *_sellerItemsURL;
    NSString *_aboutMeURL;
    NSString *_myWorldURL;
    NSString *_myWorldSmallImage;
    NSString *_myWorldLargeImage;
    NSString *_reviewsAndGuidesURL;
    NSString *_feedbackDetailsURL;
    NSNumber *_positiveFeedbackPercent;
    NSString *_sellerLevel;
    NSNumber *_topRatedSeller;
    NSMutableArray *_any;

}


/**
 
 The user's unique eBay user ID.
 <br />
 <br />
 When reporting UserIDs in bidding situations (such was when listing
 the high bidder in an auction), eBay replaces the UserID value with
 an anonymous bidder name value, such as "a***o".
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *userID;

/**
 
 Indicates whether the user has chosen to make their feedback score and
 feedback details private (hidden from other users). Note that the percentage
 of positive feedback can still be returned, even if other feedback details are
 private. If a bidder's user information is made
 anonymous, the value -99 is returned.
 
 
 type : NSNumber, wrapper for primitive bool
*/
@property (nonatomic, retain) NSNumber *feedbackPrivate;

/**
 
 Visual indicator of user's feedback score.
 
 
 type: string constant in Shopping_FeedbackRatingStarCodeType.h
*/
@property (nonatomic, retain) NSString *feedbackRatingStar;

/**
 
 The aggregate feedback score of a user. A user's feedback score is the net
 positive feedback minus the net negative feedback left for the user.
 <br>
 <br>
 Feedback scores are a quantitative expression of the desirability of dealing with
 a user as a buyer or a seller in transactions. Each transaction can result in one
 feedback entry for a given user. (The buyer can leave feedback for the seller, and
 the seller can leave feedback for the buyer.) That one feedback can be positive,
 negative, or neutral. The aggregate feedback score of a user represents that
 user's overall feedback score (referred to as a "feedback rating" on the eBay
 site). If the user has chosen to make their feedback private, then FeedbackScore
 is not returned and FeedbackPrivate is returned with a value of true.
 <br>
 <br>
 If a bidder's user information is made anonymous, the value -99 is returned.
 
 
 type : NSNumber, wrapper for primitive int
*/
@property (nonatomic, retain) NSNumber *feedbackScore;

/**
 
 Indicates whether eBay has made this user's information anonymous.
 This occurs when the listing prices (reserve, current, or Buy It Now)
 reach or exceed a certain amount (such as $200 USD at the time of this
 writing).
 <br>
 <br>
 If true, certain other fields about this user are not returned, or their values
 include no identifying characteristics. (The rules are explained in the
 description of each field.) If false, all user-specific fields contain the user's
 actual data.
 
 
 type : NSNumber, wrapper for primitive bool
*/
@property (nonatomic, retain) NSNumber *userAnonymized;

/**
 
 If true, identifies a new user who has been a registered eBay user for 30 days
 or less. Always false after the user has been registered for more than 30
 days. Does not indicate an ID change.
 
 
 type : NSNumber, wrapper for primitive bool
*/
@property (nonatomic, retain) NSNumber *newUser;

/**
 
 The date the specified user originally registered with eBay. If a bidder's user
 information is made anonymous, the value -99 is returned.
 
 
 type : NSDate, wrapper for primitive date
*/
@property (nonatomic, retain) NSDate *registrationDate;

/**
 
 The eBay site with which the user is registered. If a bidder's user information is
 made anonymous, the value -99 is returned.
 
 
 type: string constant in Shopping_SiteCodeType.h
*/
@property (nonatomic, retain) NSString *registrationSite;

/**
 
 The registration-related status of the user.
 
 
 type: string constant in Shopping_UserStatusCodeType.h
*/
@property (nonatomic, retain) NSString *status;

/**
 
 Type of seller account.
 
 
 type: string constant in Shopping_SellerBusinessCodeType.h
*/
@property (nonatomic, retain) NSString *sellerBusinessType;

/**
 
 The URL of the seller's eBay Store page.
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *storeURL;

/**
 
 The name of the seller's eBay Store.
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *storeName;

/**
 
 URL for seller's other items.
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *sellerItemsURL;

/**
 
 A link to the user's AboutMe page.
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *aboutMeURL;

/**
 
 A link to the URL of the user's MyWorld page.
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *myWorldURL;

/**
 
 Location of a user's image on the MyWorld page (small version).
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *myWorldSmallImage;

/**
 
 Location of a user's image on the MyWorld page (large version).
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *myWorldLargeImage;

/**
 
 The URL of reviews and guides.
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *reviewsAndGuidesURL;

/**
 
 The URL of feedback details.
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *feedbackDetailsURL;

/**
 
 A seller's positive feedback score. The percentage value of a seller's
 positive feedback is calculated by dividing the seller's positive feedback
 score by their negative feedback score. The last 12 months of feedback
 scores are taken into consideration for this calculation.
 
 
 type : NSNumber, wrapper for primitive float
*/
@property (nonatomic, retain) NSNumber *positiveFeedbackPercent;

/**
 
 The user's eBay PowerSeller tier. No longer returned for the US, DE/AT/CH, and 
 UK/IE sites. Note that SellerLevel may be suppressed for other sites, as well. 
 
 
 type: string constant in Shopping_SellerLevelCodeType.h
*/
@property (nonatomic, retain) NSString *sellerLevel;

/**
 
 Returned when seller is certified as a top-rated seller, and is qualified for benefits such as final value fee
 discount and increased visibility in fixed-price searches.
 
 
 type : NSNumber, wrapper for primitive bool
*/
@property (nonatomic, retain) NSNumber *topRatedSeller;

/**
 (public property)
 
 entry type : PicoAnyElement, wrapper for primitive anyelement
*/

@property (nonatomic, retain) NSMutableArray *any;


@end
